@@ -18,21 +18,21 @@ extern "C" {
  *
  * the version string like "1.2.3"
  */
-#define LIBXSLT_DOTTED_VERSION "1.0.17"
+#define LIBXSLT_DOTTED_VERSION "1.0.31"
 
 /**
  * LIBXSLT_VERSION:
  *
  * the version number: 1.2.3 value is 1002003
  */
-#define LIBXSLT_VERSION 10017
+#define LIBXSLT_VERSION 10031
 
 /**
  * LIBXSLT_VERSION_STRING:
  *
  * the version number string, 1.2.3 value is "1002003"
  */
-#define LIBXSLT_VERSION_STRING "10017"
+#define LIBXSLT_VERSION_STRING "10031"
 
 /**
  * WITH_XSLT_DEBUG:
@@ -65,6 +65,23 @@ extern "C" {
 #define DEBUG_MEMORY_LOCATION
 #endif
 
+/**
+ * XSLT_NEED_TRIO:
+ *
+ * should be activated in the existing libc library lacks some of the
+ * string formatting function, in that case reuse the Trio ones already
+ * compiled in the libxml2 library.
+ */
+
+#if 0
+#define XSLT_NEED_TRIO
+#endif
+#ifdef __VMS
+#ifndef XSLT_NEED_TRIO
+#define XSLT_NEED_TRIO
+#endif
+#endif
+
 /**
  * WITH_XSLT_DEBUGGER:
  *
@@ -73,8 +90,10 @@ extern "C" {
  * On by default unless --without-debugger is passed to configure
  */
 #if 1
+#ifndef WITH_DEBUGGER
 #define WITH_DEBUGGER
 #endif
+#endif
 
 /**
  * ATTRIBUTE_UNUSED:
@@ -83,10 +102,8 @@ extern "C" {
  */
 #ifdef __GNUC__
 #ifdef HAVE_ANSIDECL_H
-#ifndef __FreeBSD__
 #include <ansidecl.h>
 #endif
-#endif
 #ifndef ATTRIBUTE_UNUSED
 #define ATTRIBUTE_UNUSED
 #endif
